@@ -1,7 +1,7 @@
 package App::CSVUtils;
 
-our $DATE = '2016-11-15'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2016-11-16'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -193,6 +193,10 @@ $SPEC{csvutil} = {
                 'delete-field',
                 'add-field',
                 'sort-fields',
+                'sum',
+                'avg',
+                'select-row',
+                'convert-to-hash',
             ]],
             req => 1,
             pos => 0,
@@ -233,6 +237,8 @@ sub csvutil {
     my $field_idx;
     my $sorted_fields;
     my @summary_row;
+    my $selected_row;
+    my $row_spec_sub;
 
     while (my $row = $csv->getline($fh)) {
         $i++;
@@ -271,6 +277,21 @@ sub csvutil {
             if ($action eq 'sum' || $action eq 'avg') {
                 @summary_row = map {0} @$row;
             }
+            if ($action eq 'select-row') {
+                my $spec = $args{row_spec};
+                my @codestr;
+                for my $spec_item (split /\s*,\s*/, $spec) {
+                    if ($spec_item =~ /\A\d+\z/) {
+                        push @codestr, "(\$i == $spec_item)";
+                    } elsif ($spec_item =~ /\A(\d+)\s*-\s*(\d+)\z/) {
+                        push @codestr, "(\$i >= $1 && \$i <= $2)";
+                    } else {
+                        return [400, "Invalid row specification '$spec_item'"];
+                    }
+                }
+                $row_spec_sub = eval 'sub { my $i = shift; '.join(" || ", @codestr).' }';
+                return [400, "BUG: Invalid row_spec code: $@"] if $@;
+            }
         } # if i==1 (header row)
 
         if ($action eq 'list-field-names') {
@@ -362,9 +383,26 @@ sub csvutil {
                 $res .= _get_csv_row($csv, $row, $i)
                     if $args{_with_data_rows};
             }
+        } elsif ($action eq 'select-row') {
+            if ($i == 1 || $row_spec_sub->($i)) {
+                $res .= _get_csv_row($csv, $row, $i);
+            }
+        } elsif ($action eq 'convert-to-hash') {
+            if ($i == $args{_row_number}) {
+                $selected_row = $row;
+            }
         } else {
             return [400, "Unknown action '$action'"];
         }
+    } # while getline()
+
+    if ($action eq 'convert-to-hash') {
+        $selected_row //= [];
+        my $hash = {};
+        for (0..$#{$fields}) {
+            $hash->{ $fields->[$_] } = $selected_row->[$_];
+        }
+        return [200, "OK", $hash];
     }
 
     if ($action eq 'sum') {
@@ -377,7 +415,6 @@ sub csvutil {
         $res .= _get_csv_row($csv, \@summary_row,
                              $args{_with_data_rows} ? $i+1 : 2);
     }
-
     [200, "OK", $res, {"cmdline.skip_format"=>1}];
 }
 
@@ -550,6 +587,46 @@ sub csv_avg {
     csvutil(%args, action=>'avg', _with_data_rows=>$args{with_data_rows});
 }
 
+$SPEC{csv_select_row} = {
+    v => 1.1,
+    summary => 'Only output specified row(s)',
+    args => {
+        %arg_filename_0,
+        row_spec => {
+            schema => 'str*',
+            summary => 'Row number (e.g. 2 for first data row), '.
+                'range (2-7), or comma-separated list of such (2-7,10,20-23)',
+            req => 1,
+            pos => 1,
+        },
+    },
+};
+sub csv_select_row {
+    my %args = @_;
+
+    csvutil(%args, action=>'select-row');
+}
+
+$SPEC{csv_convert_to_hash} = {
+    v => 1.1,
+    summary => 'Return a hash of field names as keys and first row as values',
+    args => {
+        %arg_filename_0,
+        row_number => {
+            schema => ['int*', min=>2],
+            default => 2,
+            summary => 'Row number (e.g. 2 for first data row)',
+            pos => 1,
+        },
+    },
+};
+sub csv_convert_to_hash {
+    my %args = @_;
+
+    csvutil(%args, action=>'convert-to-hash',
+            _row_number=>$args{row_number} // 2);
+}
+
 
 1;
 # ABSTRACT: CLI utilities related to CSV
@@ -566,7 +643,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.007 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2016-11-15.
+This document describes version 0.008 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2016-11-16.
 
 =head1 DESCRIPTION
 
@@ -578,6 +655,8 @@ This distribution contains the following CLI utilities:
 
 =item * L<csv-avg>
 
+=item * L<csv-convert-to-hash>
+
 =item * L<csv-delete-field>
 
 =item * L<csv-list-field-names>
@@ -586,6 +665,8 @@ This distribution contains the following CLI utilities:
 
 =item * L<csv-replace-newline>
 
+=item * L<csv-select-row>
+
 =item * L<csv-sort-fields>
 
 =item * L<csv-sum>
@@ -668,6 +749,38 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 csv_convert_to_hash(%args) -> [status, msg, result, meta]
+
+Return a hash of field names as keys and first row as values.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<filename>* => I<filename>
+
+Input CSV file.
+
+=item * B<row_number> => I<int> (default: 2)
+
+Row number (e.g. 2 for first data row).
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 csv_delete_field(%args) -> [status, msg, result, meta]
 
 Delete a field from CSV file.
@@ -805,6 +918,38 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 csv_select_row(%args) -> [status, msg, result, meta]
+
+Only output specified row(s).
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<filename>* => I<filename>
+
+Input CSV file.
+
+=item * B<row_spec>* => I<str>
+
+Row number (e.g. 2 for first data row), range (2-7), or comma-separated list of such (2-7,10,20-23).
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 csv_sort_fields(%args) -> [status, msg, result, meta]
 
 Sort CSV fields.
